==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/usermanager/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 */
$lang['menu']                  = 'Správa uživatelů';
$lang['noauth']                = '(autentizace uživatelů není k dispozici)';
$lang['nosupport']             = '(správa uživatelů není podporována)';
$lang['badauth']               = 'chybná metoda autentizace';
$lang['user_id']               = 'Uživatel';
$lang['user_pass']             = 'Heslo';
$lang['user_name']             = 'Celé jméno';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Skupiny';
$lang['field']                 = 'Položka';
$lang['value']                 = 'Hodnota';
$lang['add']                   = 'Přidat';
$lang['delete']                = 'Smazat';
$lang['delete_selected']       = 'Smazat vybrané';
$lang['edit']                  = 'Upravit';
$lang['edit_prompt']           = 'Upravit uživatele';
$lang['modify']                = 'Uložit změny';
$lang['search']                = 'Hledání';
$lang['search_prompt']         = 'Prohledat';
$lang['clear']                 = 'Zrušit vyhledávací filtr';
$lang['filter']                = 'Filtr';
$lang['summary']               = 'Zobrazuji uživatele %1$d-%2$d z %3$d nalezených. Celkem %4$d uživatelů.';
$lang['nonefound']             = 'Žadný uživatel nenalezen. Celkem %d uživatelů.';
$lang['delete_ok']             = '%d uživatelů smazáno';
$lang['delete_fail']           = '%d uživatelů nelze smazat.';
$lang['update_ok']             = 'Uživatel upraven';
$lang['update_fail']           = 'Úprava uživatele selhala';
$lang['update_exists']         = 'Jméno nelze změnit, jelikož zadané uživatelské jméno (%s) již existuje (ostatní změny ale budou provedeny).';
$lang['start']                 = 'první';
$lang['prev']                  = 'předchozí';
$lang['next']                  = 'další';
$lang['last']                  = 'poslední';
$lang['edit_usermissing']      = 'Vybraný uživatel nebyl nalezen, zadané uživatelského mohlo být smazáno nebo změněno.';
$lang['user_notify']           = 'Upozornit uživatele';
$lang['note_notify']           = 'Maily s upozorněním se budou posílat pouze, když uživatel dostává nové heslo.';
$lang['note_group']            = 'Noví uživatelé budou přidáváni do této výchozí skupiny (%s), pokud pro ně není uvedena žádná skupina.';
$lang['add_ok']                = 'Uživatel úspěšně vytvořen';
$lang['add_fail']              = 'Vytvoření uživatele selhalo';
$lang['notify_ok']             = 'Odeslán mail s upozorněním';
$lang['notify_fail']           = 'Mail s upozorněním nebylo možno odeslat';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 */
$lang['menu']                  = 'Správa uživatelů';
$lang['noauth']                = '(autentizace uživatelů není k dispozici)';
$lang['nosupport']             = '(správa uživatelů není podporována)';
$lang['badauth']               = 'chybná metoda autentizace';
$lang['user_id']               = 'Uživatel';
$lang['user_pass']             = 'Heslo';
$lang['user_name']             = 'Celé jméno';
$lang['user_mail']             = 'E-mail';
$lang['user_groups']           = 'Skupiny';
$lang['field']                 = 'Položka';
$lang['value']                 = 'Hodnota';
$lang['add']                   = 'Přidat';
$lang['delete']                = 'Smazat';
$lang['delete_selected']       = 'Smazat vybrané';
$lang['edit']                  = 'Upravit';
$lang['edit_prompt']           = 'Upravit uživatele';
$lang['modify']                = 'Uložit změny';
$lang['search']                = 'Hledání';
$lang['search_prompt']         = 'Prohledat';
$lang['clear']                 = 'Zrušit vyhledávací filtr';
$lang['filter']                = 'Filtr';
$lang['summary']               = 'Zobrazuji uživatele %1$d-%2$d z %3$d nalezených. Celkem %4$d uživatelů.';
$lang['nonefound']             = 'Žadný uživatel nenalezen. Celkem %d uživatelů.';
$lang['delete_ok']             = '%d uživatelů smazáno';
$lang['delete_fail']           = '%d uživatelů nelze smazat.';
$lang['update_ok']             = 'Uživatel upraven';
$lang['update_fail']           = 'Úprava uživatele selhala';
$lang['update_exists']         = 'Jméno nelze změnit, jelikož zadané uživatelské jméno (%s) již existuje (ostatní změny ale budou provedeny).';
$lang['start']                 = 'první';
$lang['prev']                  = 'předchozí';
$lang['next']                  = 'další';
$lang['last']                  = 'poslední';
$lang['edit_usermissing']      = 'Vybraný uživatel nebyl nalezen, zadané uživatelského mohlo být smazáno nebo změněno.';
$lang['user_notify']           = 'Upozornit uživatele';
$lang['note_notify']           = 'Maily s upozorněním se budou posílat pouze, když uživatel dostává nové heslo.';
$lang['note_group']            = 'Noví uživatelé budou přidáváni do této výchozí skupiny (%s), pokud pro ně není uvedena žádná skupina.';
$lang['note_pass']             = 'Heslo bude automaticky vygenerováno pokud je pole ponacháno prázdné a je zapnutá notifikace uživatele.';
$lang['add_ok']                = 'Uživatel úspěšně vytvořen';
$lang['add_fail']              = 'Vytvoření uživatele selhalo';
$lang['notify_ok']             = 'Odeslán mail s upozorněním';
$lang['notify_fail']           = 'Mail s upozorněním nebylo možno odeslat';
